Jae

Trait Jae 

pub trait Jae<T> {
    // Required method
    fn jae(&mut self, op1: T);
}
Trait for jae instruction kinds.

Required Methods

fn jae(&mut self, op1: T)

Emit a conditional jump if above or equal (CF=0). This handles the flags from an unsigned arithmetic operation.

Implementors

Source

impl Jae<&mut Label> for Asm