pub trait Jae<T> { // Required method fn jae(&mut self, op1: T); }
Trait for jae instruction kinds.
jae
Emit a conditional jump if above or equal (CF=0). This handles the flags from an unsigned arithmetic operation.
CF=0