pub trait Jge<T> { // Required method fn jge(&mut self, op1: T); }
Trait for jge instruction kinds.
jge
Emit a conditional jump if greater or equal (SF=OF). This handles the flags from a signed arithmetic operation.
SF=OF